from setuptools import setup

setup(name='st3r_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['st3r_distributions'],
      authoer=['st3r'],
      zip_safe=False)
